package be.iminds.ilabt.jfed.espec.model;

import javax.annotation.Nonnull;

/**
 * FileSource
 */
public class GeneratedRandomFileSource extends FileSource {
    @Nonnull private final String format;
    private final int length;

    public GeneratedRandomFileSource(@Nonnull SourceType sourceType, @Nonnull String value, @Nonnull String basename,
                                     @Nonnull String format, int length) {
       super(sourceType, value, basename);
       this.format = format;
       this.length = length;

       String formatMatch = format.trim().toLowerCase();
       switch (formatMatch) {
           case "binary":
           case "base64":
           case "password":
           case "alphanum":
               break;
           default:
               throw new IllegalArgumentException("generated:random does not have a format \""+format+"\"");
       }
    }

    @Nonnull
    public String getFormat() {
        return format;
    }

    public int getLength() {
        return length;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (!(o instanceof GeneratedRandomFileSource)) return false;
        if (!super.equals(o)) return false;

        GeneratedRandomFileSource that = (GeneratedRandomFileSource) o;

        if (length != that.length) return false;
        return format.equals(that.format);
    }

    @Override
    public int hashCode() {
        int result = super.hashCode();
        result = 31 * result + format.hashCode();
        result = 31 * result + length;
        return result;
    }

    @Override
    public String toString() {
        return "GeneratedRandomFileSource{" +
                "type=" + type +
                ", value='" + value + '\'' +
                ", basename='" + basename + '\'' +
                ", format='" + format + '\'' +
                ", length=" + length +
                '}';
    }
}
